@@ -1,5 +1,6 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+import datetime
 from decimal import Decimal
 
 from amaascore.core.amaas_model import AMaaSModel
@@ -7,10 +8,13 @@ from amaascore.core.amaas_model import AMaaSModel
 
 class Position(AMaaSModel):
 
-    def __init__(self, asset_manager_id, book_id, asset_id, quantity, *args, **kwargs):
-
+    def __init__(self, asset_manager_id, book_id, account_id, accounting_type,
+                 asset_id, quantity, client_id=None, *args, **kwargs):
+                 
         self.asset_manager_id = asset_manager_id
         self.book_id = book_id
+        self.account_id = account_id
+        self.accounting_type = accounting_type
         self.asset_id = asset_id
         self.quantity = quantity
         super(Position, self).__init__(*args, **kwargs)
